@@ -3,7 +3,7 @@ var searchData=
   ['s_5fptype',['s_pType',['../a00051.html#aa5b41a1b31828cfa322891edaa08b13c',1,'com::sun::star::uno::Array']]],
   ['seconds',['Seconds',['../a00198.html#a97f504b07d37dfb242c1716a08784802',1,'TimeValue::Seconds()'],['../a00006.html#ad197c5802bf50cce01faf8786b7504c1',1,'_oslDateTime::Seconds()']]],
   ['signal',['Signal',['../a00147.html#a90c8d16605cd687001dd637acb411eef',1,'oslSignalInfo']]],
-  ['size',['size',['../a00068.html#aec62e4d35d06f90b41cabc0d13dde922',1,'rtl::libreoffice_internal::ConstCharArrayDetector&lt; const char[N], T &gt;::size()'],['../a00146.html#a0596b91fd07cb65933ff9c3c5e73f120',1,'oslProcessInfo::Size()']]],
+  ['size',['Size',['../a00146.html#a0596b91fd07cb65933ff9c3c5e73f120',1,'oslProcessInfo']]],
   ['structsize',['StructSize',['../a00012.html#aed0b013ab18b23707b7b2788ef4fdd5e',1,'_rtl_TextEncodingInfo']]],
   ['systemtime',['SystemTime',['../a00146.html#a1a6d03b9ad4cdcedf887134d833fc71d',1,'oslProcessInfo']]]
 ];
